@@ -24,18 +24,19 @@ else
 fi
 
 case "$VERSION_ID" in
-	"16.04") PACKAGES=('libncursesw5-dev' 'libncursesw5' 'libcpuid15-git' 'libpci3' 'libglfw3-dev' 'libglfw3' 'libprocps4');;
-	"18.04") PACKAGES=('libncursesw5-dev' 'libncursesw5' 'libcpuid15-git' 'libpci3' 'libglfw3-dev' 'libglfw3' 'libprocps6');;
-	"20.04") PACKAGES=('libncurses-dev'   'libncursesw6' 'libcpuid15-git' 'libpci3' 'libglfw3-dev' 'libglfw3' 'libprocps8');;
-	*)       echo "Unsupported Ubuntu version: $VERSION_ID" ; exit 1;;
+	"20.04") # Focal Fossa
+		PACKAGES=('libncurses-dev' 'libncursesw6' 'libpci3' 'libprocps8' 'libglfw3-dev' 'libglfw3' 'libglvnd-dev' 'libvulkan-dev' 'ocl-icd-opencl-dev')
+		;;
+	"22.04") # Jammy Jellyfish
+		PACKAGES=('libncurses-dev' 'libncursesw6' 'libpci3' 'libprocps8' 'libglfw3-dev' 'libglfw3' 'libglvnd-dev' 'libvulkan-dev' 'ocl-icd-opencl-dev')
+		;;
+	*)
+		echo "Unsupported Ubuntu version: $VERSION_ID" ; exit 1
+		;;
 esac
 
-echo "Add OBS repository"
-echo "deb http://download.opensuse.org/repositories/home:/Xorg/xUbuntu_${VERSION_ID}/ /" | sudo tee /etc/apt/sources.list.d/home:Xorg.list
-curl -sSL "https://download.opensuse.org/repositories/home:Xorg/xUbuntu_${VERSION_ID}/Release.key" | sudo apt-key add -
-sudo apt-get update -qq
-
 echo "Install packages"
+sudo apt-get update -y -qq
 sudo apt-get install -y -qq \
 	cmake \
 	ninja-build \
@@ -45,7 +46,6 @@ sudo apt-get install -y -qq \
 	"${PACKAGES[@]}" \
 	libgtk-3-0 \
 	libgtk-3-dev \
-	libcpuid-dev-git \
 	libpci-dev \
 	opencl-headers \
 	ocl-icd-libopencl1 \
