@@ -1,5 +1,5 @@
 /****************************************************************************
-*    Copyright © 2014-2022 Xorg
+*    Copyright © 2014-2022 The Tumultuous Unicorn Of Darkness
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
@@ -60,6 +60,7 @@ const Technology_DB technology_intel[] =
 	{  6,          54,          -1,          32 }, // Atom Cedarview
 	{  6,          70,          -1,          22 }, // Haswell (Crystalwell, L4 cache)
 	{  6,         102,          -1,          10 }, // Cannon Lake
+	{  6,         150,          -1,          10 }, // Tremont (Elkhart Lake)
 	{  7,           7,          -1,         250 }, // PIII Katmai
 	{  7,          23,          -1,          45 }, // C2 Wolfdale / Yorkfield / Penryn
 	{  7,          55,          -1,          22 }, // Atom Bay Trail
@@ -75,13 +76,16 @@ const Technology_DB technology_intel[] =
 	{ 10,          42,          -1,          32 }, // Sandy Bridge
 	{ 10,          58,          -1,          22 }, // Ivy Bridge
 	{ 10,         122,          -1,          14 }, // Gemini Lake
+	{ 10,         138,          -1,          10 }, // Tremont (Lakefield)
 	{ 10,         154,          -1,           7 }, // Alder Lake-S
 	{ 11,          11,          -1,         130 }, // PIII Tualatine
 	{ 12,          28,          -1,          45 }, // Atom Diamondville / Pineview / Silverthorne
 	{ 12,          44,          -1,          32 }, // Westmere
 	{ 12,          60,          -1,          22 }, // Haswell
 	{ 12,          76,          -1,          14 }, // Atom Cherry Trail
+	{ 12,         108,          -1,          10 }, // Ice Lake
 	{ 12,         140,          -1,          10 }, // Tiger Lake
+	{ 12,         156,          -1,          10 }, // Tremont (Jasper Lake)
 	{ 13,          13,          -1,          90 }, // Pentium M Dothan
 	{ 13,          45,          -1,          32 }, // Sandy Bridge-E
 	{ 13,          61,          -1,          14 }, // Broadwell-U
@@ -129,6 +133,7 @@ const Technology_DB technology_amd[] =
 	{ 10,          -1,           6,         130 }, // K7 (Barton)
 	{ 10,          -1,          16,          45 }, // K10 (Thuban)
 	{ 11,          -1,          15,          65 }, // K8 (Brisbane)
+	{ 12,         124,          15,          65 }, // K8 (Sherman)
 	{ 12,          -1,          15,          90 }, // K8 (Venice/Sonora)
 	{ 15,          79,          15,          90 }, // K8 (Manila)
 	{ 15,         127,          15,          65 }, // K8 (Sparta)
@@ -138,10 +143,13 @@ const Technology_DB technology_amd[] =
 	{ -1,          32,          23,          14 }, // Zen (Dali)
 	{ -1,          24,          23,          12 }, // Zen+ (Picasso)
 	{ -1,          49,          23,           7 }, // Zen 2 (Rome/Castle Peak)
+	{ -1,          71,          23,           7 }, // Zen 2 (4700S Desktop Kit)
 	{ -1,          96,          23,           7 }, // Zen 2 (Renoir)
 	{ -1,         104,          23,           7 }, // Zen 2 (Lucienne)
 	{ -1,         113,          23,           7 }, // Zen 2 (Matisse)
+	{ -1,         132,          23,           7 }, // Zen 2 (4800S Desktop Kit)
 	{ -1,         144,          23,           7 }, // Zen 2 (Custom APU for Steam Deck)
+	{ -1,         160,          23,           6 }, // Zen 2 (Mendocino)
 	{ -1,          33,          25,           7 }, // Zen 3 (Vermeer)
 	{ -1,          80,          25,           7 }, // Zen 3 (Cezanne)
 	{ -1,           1,          25,           7 }, // Zen 3 (Milan)
@@ -229,11 +237,14 @@ const Package_DB package_amd[] =
 	{ "Matisse",                        NULL,            "AM4 (PGA-1331)"   },
 	{ "Castle Peak",                    NULL,            "SP3r2 (LGA-4094)" },
 	{ "Rome",                           NULL,            "SP3 (LGA-4094)"   },
+	{ "Mendocino",                      NULL,            "FT6 (BGA)"        },
 	/* Zen 3 */
 	{ "Cezanne",                        NULL,            "FP6 (BGA-1140)"   },
 	{ "Vermeer",                        NULL,            "AM4 (PGA-1331)"   },
 	{ "Milan",                          NULL,            "SP3 (LGA-4094)"   },
 	{ "Raphael",                        NULL,            "AM5 (LGA-1718)"   },
+	/* Zen 3+ */
+	{ "Rembrandt",                      NULL,            "FP7 (BGA-1140)"   },
 	{ NULL,                             NULL,            NULL               }
 	//Codename                          Model            Socket
 };
